@@ -478,8 +478,8 @@ class ExecutionServer(BaseServer):
         for uuid in data:
             if uuid in self.active_jobs or uuid in self.queued_jobs:
                 continue
-            if len(self.job_queue) > self.reservation_check_interval * 20:
-                break
+            #if len(self.job_queue) > self.reservation_check_interval * 20:
+            #    break
             kwargs_raw = {}
             reserved_arguments = {}
             # Load attributes into dicts for use by the system or custom functions.
